@@ -2,7 +2,7 @@
 package Paws::EC2::CreateCustomerGatewayResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has CustomerGateway => (is => 'ro', isa => 'Paws::EC2::CustomerGateway', traits => ['Unwrapped'], xmlname => 'customerGateway');
+  has CustomerGateway => (is => 'ro', isa => 'Paws::EC2::CustomerGateway', xmlname => 'customerGateway', traits => ['Unwrapped',]);
 
 }
 1;
