@@ -2,7 +2,7 @@
 package Paws::EC2::CreateRouteTableResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has RouteTable => (is => 'ro', isa => 'Paws::EC2::RouteTable', traits => ['Unwrapped'], xmlname => 'routeTable');
+  has RouteTable => (is => 'ro', isa => 'Paws::EC2::RouteTable', xmlname => 'routeTable', traits => ['Unwrapped',]);
 
 }
 1;
