@@ -2,7 +2,7 @@
 package Paws::EC2::CreateSubnetResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has Subnet => (is => 'ro', isa => 'Paws::EC2::Subnet', traits => ['Unwrapped'], xmlname => 'subnet');
+  has Subnet => (is => 'ro', isa => 'Paws::EC2::Subnet', xmlname => 'subnet', traits => ['Unwrapped',]);
 
 }
 1;
