@@ -2,8 +2,8 @@
 package Paws::EC2::DescribeInstanceStatusResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has InstanceStatuses => (is => 'ro', isa => 'ArrayRef[Paws::EC2::InstanceStatus]', traits => ['Unwrapped'], xmlname => 'instanceStatusSet');
-  has NextToken => (is => 'ro', isa => 'Str', traits => ['Unwrapped'], xmlname => 'nextToken');
+  has InstanceStatuses => (is => 'ro', isa => 'ArrayRef[Paws::EC2::InstanceStatus]', xmlname => 'instanceStatusSet', traits => ['Unwrapped',]);
+  has NextToken => (is => 'ro', isa => 'Str', xmlname => 'nextToken', traits => ['Unwrapped',]);
 
 }
 1;
