@@ -2,7 +2,7 @@
 package Paws::EC2::DescribeSubnetsResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has Subnets => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Subnet]', traits => ['Unwrapped'], xmlname => 'subnetSet');
+  has Subnets => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Subnet]', xmlname => 'subnetSet', traits => ['Unwrapped',]);
 
 }
 1;
