@@ -2,8 +2,8 @@
 package Paws::EC2::DescribeTagsResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has NextToken => (is => 'ro', isa => 'Str', traits => ['Unwrapped'], xmlname => 'nextToken');
-  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::EC2::TagDescription]', traits => ['Unwrapped'], xmlname => 'tagSet');
+  has NextToken => (is => 'ro', isa => 'Str', xmlname => 'nextToken', traits => ['Unwrapped',]);
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::EC2::TagDescription]', xmlname => 'tagSet', traits => ['Unwrapped',]);
 
 }
 1;
