@@ -2,7 +2,7 @@
 package Paws::EC2::EnableVpcClassicLinkResult {
   use Moose;
   with 'Paws::API::UnwrappedParser';
-  has Return => (is => 'ro', isa => 'Bool', traits => ['Unwrapped'], xmlname => 'return');
+  has Return => (is => 'ro', isa => 'Bool', xmlname => 'return', traits => ['Unwrapped',]);
 
 }
 1;
