@@ -3,7 +3,7 @@ package Paws::IAM::GetGroupPolicyResponse {
   use Moose;
   with 'Paws::API::ResultParser';
   has GroupName => (is => 'ro', isa => 'Str', required => 1);
-  has PolicyDocument => (is => 'ro', isa => 'Str', required => 1);
+  has PolicyDocument => (is => 'ro', isa => 'Str', decode_as => 'URLJSON', method => 'Policy', traits => ['JSONAttribute',], required => 1);
   has PolicyName => (is => 'ro', isa => 'Str', required => 1);
 
 }
